@@ -1,5 +1,5 @@
 import asyncHandler from 'express-async-handler';
-import { NotFoundError } from '@tamanu/shared/errors';
+import { NotFoundError } from '@tamanu/errors';
 
 const deleteModel = (modelName, paramName, displayName = modelName) => {
   return asyncHandler(async (req, res) => {
